package com.ghy.customer.service;

import com.ghy.customer.domain.CustomerSelection;

import java.util.List;

/**
 * 消费者选品Service接口
 *
 * @author clunt
 * @date 2023-01-15
 */
public interface ICustomerSelectionService
{
    /**
     * 查询消费者选品
     *
     * @param id 消费者选品主键
     * @return 消费者选品
     */
    public CustomerSelection selectCustomerSelectionById(String id);

    /**
     * 查询消费者选品列表
     *
     * @param customerSelection 消费者选品
     * @return 消费者选品集合
     */
    public List<CustomerSelection> selectCustomerSelectionList(CustomerSelection customerSelection);

    /**
     * 新增消费者选品
     *
     * @param customerSelection 消费者选品
     * @return 结果
     */
    public int insertCustomerSelection(CustomerSelection customerSelection);

    /**
     * 修改消费者选品
     *
     * @param customerSelection 消费者选品
     * @return 结果
     */
    public int updateCustomerSelection(CustomerSelection customerSelection);

    /**
     * 批量删除消费者选品
     *
     * @param ids 需要删除的消费者选品主键集合
     * @return 结果
     */
    public int deleteCustomerSelectionByIds(String ids);

    /**
     * 删除消费者选品信息
     *
     * @param id 消费者选品主键
     * @return 结果
     */
    public int deleteCustomerSelectionById(String id);
}
